@@ -1,5 +1,5 @@
 import sys
 import os
 PYTHON_PATH = sys.executable
-file_path = sys.path[-1] + '/server/server.py'
-os.system(f'{PYTHON_PATH} {file_path}')
+file_path = os.getcwd() + '\server.py'
+os.system(f'{PYTHON_PATH} {file_path}')
\ No newline at end of file
